<?php

namespace Modules\Qc\Http\Controllers;

use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Qc\Entities\DailyLabReportDay;
use Modules\Qc\Entities\DailyLabReportDayAttachment;

class DailyLabReportDayController extends Controller
{
    public function uploadAttachment(Request $request)
    {
        try {
            $token = $request->get('attachment_token');
            $file = $request->file('file');
            $file_name = $file->getClientOriginalName();
            $filename = uniqid() . '_' . time() . '.' . $file_name;
            $file->move(public_path('dlr_day'), $filename);

            $dlr_day_attachment = new DailyLabReportDayAttachment();
            $dlr_day_attachment->dlr_day_id = 0;
            $dlr_day_attachment->path = $filename;
            $dlr_day_attachment->token = $token;
            $dlr_day_attachment->save();

            $responseBody = $this->responseBody(true, "DailyLabReportDayController", "uploaded", null);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "DailyLabReportDayController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function allDailyLabReportDays()
    {
        try {
            $query = "SELECT
            qc_daily_lab_report_day.*,
            qc_daily_lab_report_day_attachments.path,
            pp_customer_order_plans_data.manufacturing_order_no,
            st_products.product_name,
            hr_employee_sites.site
        FROM
            qc_daily_lab_report_day_attachments
            INNER JOIN
            qc_daily_lab_report_day
            ON
                qc_daily_lab_report_day_attachments.dlr_day_id = qc_daily_lab_report_day.dlr_day_id
            INNER JOIN
            pp_customer_order_plans_data
            ON
                qc_daily_lab_report_day.customer_order_plan_data_id = pp_customer_order_plans_data.customer_order_plan_data_id
            INNER JOIN
            st_products
            ON
                pp_customer_order_plans_data.product_id = st_products.product_primary_id
            INNER JOIN
            hr_employee_sites
            ON
                qc_daily_lab_report_day.factory = hr_employee_sites.site_id
                GROUP BY
            qc_daily_lab_report_day.dlr_day_id
            ";

            $records = DB::select($query);
            $result = array();
            foreach ($records as $record) {
                array_push($result, [
                    "dlr_day_id" => $record->dlr_day_id,
                    "reference_no" => $record->reference_no,
                    "product_name" => $record->product_name,
                    "manufacturing_order_no" => $record->manufacturing_order_no,
                    "date" => $record->date,
                    "factory" => $record->site,
                    "description" => $record->description,
                    "path" => $record->path,
                ]);
            }
            $responseBody = $this->responseBody(true, "DailyLabReportDayController", "allDailyLabReportDays", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "DailyLabReportDayController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    public function saveDailyLabReportDay(Request $request)
    {
        try {
            $sqr = new DailyLabReportDay();
            $sqr->user_id = Auth::user()->id;
            $sqr->reference_no = $request->get('reference_no');
            $sqr->date = $request->get('date');
            $sqr->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');
            $sqr->factory = $request->get('factory');
            $sqr->description = $request->get('description');
            if ($sqr->save()) {
                $token = $request->get('attachment_token');
                $attachment = DailyLabReportDayAttachment::where('token', '=', $token)->first();
                if ($attachment) {
                    $attachment->dlr_day_id = $sqr->dlr_day_id;
                    $attachment->update();
                }
            }
            $responseBody = $this->responseBody(true, "DailyLabReportDayController", "saveDailyLabReportDay", $attachment);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "DailyLabReportDayController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    public function update(Request $request, $id)
    {
        try {
            $sqr =  DailyLabReportDay::find($id);
            $sqr->user_id = Auth::user()->id;
            $sqr->reference_no = $request->get('reference_no');
            $sqr->date = $request->get('date');
            $sqr->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');
            $sqr->factory = $request->get('factory');
            $sqr->description = $request->get('description');
            if ($sqr->update()) {
                $token = $request->get('attachment_token');
                $attachments = DailyLabReportDayAttachment::where('token', '=', $token)->get();
                if (count($attachments) > 1) {
                    if ($this->delete($id)) {
                        $attachment = DailyLabReportDayAttachment::where('token', '=', $token)->first();
                        $attachment->dlr_day_id = (int)$id;
                        $attachment->update();
                    }
                }
                $responseBody = $this->responseBody(true, "DailyLabReportDayController", "updated", count($attachments));
            }
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "DailyLabReportDayController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }




    public function delete($id)
    {
        try {
            $attachment = DailyLabReportDayAttachment::where('dlr_day_id', '=', $id)->get();
            foreach ($attachment as $data) {
                $data->delete();
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }


    public function deleteRecord($id)
    {
        try {
            $record = DailyLabReportDay::where('dlr_day_id', '=', $id)->get();
            foreach ($record as $data) {
                $data->delete();
            }
            $attachment = DailyLabReportDayAttachment::where('dlr_day_id', '=', $id)->get();
            foreach ($attachment as $data) {
                $data->delete();
            }
            $responseBody = $this->responseBody(true, "DailyLabReportDayController", "deleted", null);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "DailyLabReportDayController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function getDlrDayData($id)
    {
        try {
            $query = "SELECT
            qc_daily_lab_report_day.*,
            qc_daily_lab_report_day_attachments.token
        FROM
            qc_daily_lab_report_day_attachments
            INNER JOIN
            qc_daily_lab_report_day
            ON
                qc_daily_lab_report_day_attachments.dlr_day_id = qc_daily_lab_report_day.dlr_day_id
        WHERE
            qc_daily_lab_report_day.dlr_day_id = {$id}";

            $sqr =  DB::select($query);

            $responseBody = $this->responseBody(true, "DailyLabReportDayController", "getDlrDayData", $sqr[0]);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "DailyLabReportDayController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }



    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
