<?php

namespace Modules\Qc\Http\Controllers;

use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Qc\Entities\MicroTestingSummary;
use Modules\Qc\Entities\MicroTestingSummaryAttachment;

class MicroTestingSummaryController extends Controller
{
    public function uploadAttachment(Request $request)
    {
        try {
            $token = $request->get('attachment_token');
            $file = $request->file('file');
            $file_name = $file->getClientOriginalName();
            $filename = uniqid() . '_' . time() . '.' . $file_name;
            $file->move(public_path('micro_testing'), $filename);

            $micro_testing_attachment = new MicroTestingSummaryAttachment();
            $micro_testing_attachment->micro_testing_id = 0;
            $micro_testing_attachment->path = $filename;
            $micro_testing_attachment->token = $token;
            $micro_testing_attachment->save();

            $responseBody = $this->responseBody(true, "MicroTestingSummaryController", "uploaded", null);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "MicroTestingSummaryController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function allRecords()
    {
        try {
            $query = "SELECT
            qc_micro_testing_summaries.*,
            qc_micro_testing_summary_attachments.path,
            pp_customer_order_plans_data.manufacturing_order_no,
            st_products.product_name,
            hr_employee_sites.site
        FROM
            qc_micro_testing_summary_attachments
            INNER JOIN
            qc_micro_testing_summaries
            ON
                qc_micro_testing_summary_attachments.micro_testing_id = qc_micro_testing_summaries.micro_testing_id
            INNER JOIN
            pp_customer_order_plans_data
            ON
                qc_micro_testing_summaries.customer_order_plan_data_id = pp_customer_order_plans_data.customer_order_plan_data_id
            INNER JOIN
            st_products
            ON
                pp_customer_order_plans_data.product_id = st_products.product_primary_id
            INNER JOIN
            hr_employee_sites
            ON
                qc_micro_testing_summaries.factory = hr_employee_sites.site_id
                GROUP BY
            qc_micro_testing_summaries.micro_testing_id
            ";

            $records = DB::select($query);
            $result = array();
            foreach ($records as $record) {
                array_push($result, [
                    "micro_testing_id" => $record->micro_testing_id,
                    "reference_no" => $record->reference_no,
                    "product_name" => $record->product_name,
                    "manufacturing_order_no" => $record->manufacturing_order_no,
                    "date" => $record->date,
                    "factory" => $record->site,
                    "description" => $record->description,
                    "path" => $record->path,
                ]);
            }
            $responseBody = $this->responseBody(true, "MicroTestingSummaryController", "allRecords", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "MicroTestingSummaryController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    public function saveRecord(Request $request)
    {
        try {
            $micro = new MicroTestingSummary();
            $micro->user_id = Auth::user()->id;
            $micro->reference_no = $request->get('reference_no');
            $micro->date = $request->get('date');
            $micro->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');
            $micro->factory = $request->get('factory');
            $micro->description = $request->get('description');
            if ($micro->save()) {
                $token = $request->get('attachment_token');
                $attachment = MicroTestingSummaryAttachment::where('token', '=', $token)->first();
                if ($attachment) {
                    $attachment->micro_testing_id = $micro->micro_testing_id;
                    $attachment->update();
                }
            }
            $responseBody = $this->responseBody(true, "MicroTestingSummaryController", "saveRecord", $attachment);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "MicroTestingSummaryController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    public function update(Request $request, $id)
    {
        try {
            $micro = MicroTestingSummary::find($id);
            $micro->user_id = Auth::user()->id;
            $micro->reference_no = $request->get('reference_no');
            $micro->date = $request->get('date');
            $micro->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');
            $micro->factory = $request->get('factory');
            $micro->description = $request->get('description');
            if ($micro->update()) {
                $token = $request->get('attachment_token');
                $attachments = MicroTestingSummaryAttachment::where('token', '=', $token)->get();
                if (count($attachments) > 1) {
                    if ($this->delete($id)) {
                        $attachment = MicroTestingSummaryAttachment::where('token', '=', $token)->first();
                        $attachment->micro_testing_id = (int)$id;
                        $attachment->update();
                    }
                }
                $responseBody = $this->responseBody(true, "MicroTestingSummaryController", "updated", count($attachments));
            }
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "MicroTestingSummaryController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }




    public function delete($id)
    {
        try {
            $attachment = MicroTestingSummaryAttachment::where('micro_testing_id', '=', $id)->get();
            foreach ($attachment as $data) {
                $data->delete();
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }


    public function deleteRecord($id)
    {
        try {
            $record = MicroTestingSummary::where('micro_testing_id', '=', $id)->get();
            foreach ($record as $data) {
                $data->delete();
            }
            $attachment = MicroTestingSummaryAttachment::where('micro_testing_id', '=', $id)->get();
            foreach ($attachment as $data) {
                $data->delete();
            }
            $responseBody = $this->responseBody(true, "MicroTestingSummaryController", "deleted", null);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "MicroTestingSummaryController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function getData($id)
    {
        try {
            $query = "SELECT
            qc_micro_testing_summaries.*,
            qc_micro_testing_summary_attachments.token
        FROM
            qc_micro_testing_summary_attachments
            INNER JOIN
            qc_micro_testing_summaries
            ON
                qc_micro_testing_summary_attachments.micro_testing_id = qc_micro_testing_summaries.micro_testing_id
        WHERE
            qc_micro_testing_summaries.micro_testing_id = {$id}";

            $micro =  DB::select($query);

            $responseBody = $this->responseBody(true, "MicroTestingSummaryController", "getData", $micro[0]);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "MicroTestingSummaryController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }



    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
