<?php

namespace Modules\Qc\Http\Controllers;

use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Qc\Entities\NcrRecordAttachment;
use Modules\Qc\Entities\NcrRecord;

class NcrRecordController extends Controller
{
    public function allNcrRecords()
    {
        try {
            $query = "SELECT
            qc_ncr_records.*,
            qc_ncr_record_attachments.path,
            pp_customer_order_plans_data.manufacturing_order_no,
            st_products.product_name,
            hr_employee_sites.site
        FROM
            qc_ncr_record_attachments
            INNER JOIN
            qc_ncr_records
            ON
                qc_ncr_record_attachments.ncr_id = qc_ncr_records.ncr_id
            INNER JOIN
            pp_customer_order_plans_data
            ON
                qc_ncr_records.customer_order_plan_data_id = pp_customer_order_plans_data.customer_order_plan_data_id
            INNER JOIN
            st_products
            ON
            pp_customer_order_plans_data.product_id = st_products.product_primary_id
            INNER JOIN
            hr_employee_sites
            ON
                qc_ncr_records.factory = hr_employee_sites.site_id
                GROUP BY
            qc_ncr_records.ncr_id";

            $records = DB::select($query);
            $result = array();
            foreach ($records as $record) {
                array_push($result, [
                    "ncr_id" => $record->ncr_id,
                    "reference_no" => $record->reference_no,
                    "product_name" => $record->product_name,
                    "manufacturing_order_no" => $record->manufacturing_order_no,
                    "date" => $record->date,
                    "factory" => $record->site,
                    "description" => $record->description,
                    "path" => $record->path,
                ]);
            }
            $responseBody = $this->responseBody(true, "NcrRecordController", "allNcrRecords", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "NcrRecordController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    public function saveNcrRecord(Request $request)
    {
        try {
            $ncr = new NcrRecord();
            $ncr->user_id = Auth::user()->id;
            $ncr->reference_no = $request->get('reference_no');
            $ncr->date = $request->get('date');
            $ncr->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');         
            $ncr->factory = $request->get('factory');
            $ncr->description = $request->get('description');
            if ($ncr->save()) {
                $token = $request->get('attachment_token');
                $attachment = NcrRecordAttachment::where('token', '=', $token)->first();
                if ($attachment) {
                    $attachment->ncr_id = $ncr->ncr_id;
                    $attachment->update();
                }
            }
            $responseBody = $this->responseBody(true, "NcrRecordController", "saveNrcRecord", $attachment);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "NcrRecordController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    public function update(Request $request, $id)
    {
        try {
            $ncr =  NcrRecord::find($id);
            $ncr->user_id = Auth::user()->id;
            $ncr->reference_no = $request->get('reference_no');
            $ncr->date = $request->get('date');
            $ncr->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');
            $ncr->factory = $request->get('factory');
            $ncr->description = $request->get('description');
            if ($ncr->update()) {
                $token = $request->get('attachment_token');
                $attachments = NcrRecordAttachment::where('token', '=', $token)->get();
                if (count($attachments) > 1) {
                    if ($this->delete($id)) {
                        $attachment = NcrRecordAttachment::where('token', '=', $token)->first();
                        $attachment->ncr_id = (int)$id;
                        $attachment->update();
                    }
                }
                $responseBody = $this->responseBody(true, "NcrRecordController", "updated", count($attachments));
            }
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "NcrRecordController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }




    public function delete($id)
    {
        try {
            $attachment = NcrRecordAttachment::where('ncr_id', '=', $id)->get();
            foreach ($attachment as $data) {
                $data->delete();
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }


    public function deleteRecord($id)
    {
        try {
            $record = NcrRecord::where('ncr_id', '=', $id)->get();
            foreach ($record as $data) {
                $data->delete();
            }
            $attachment = NcrRecordAttachment::where('ncr_id', '=', $id)->get();
            foreach ($attachment as $data) {
                $data->delete();
            }
            $responseBody = $this->responseBody(true, "NcrRecordController", "deleted", null);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "NcrRecordController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function getNcrData($id)
    {
        try {
            $query = "SELECT
            qc_ncr_records.*,
            qc_ncr_record_attachments.token
        FROM
            qc_ncr_record_attachments
            INNER JOIN
            qc_ncr_records
            ON
                qc_ncr_record_attachments.ncr_id = qc_ncr_records.ncr_id
        WHERE
            qc_ncr_records.ncr_id = {$id}";

            $ncr =  DB::select($query);

            $responseBody = $this->responseBody(true, "NcrRecordController", "getNcrData", $ncr[0]);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "NcrRecordController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }



    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
