<?php

namespace Modules\Qc\Http\Controllers;

use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Qc\Entities\QualityInspectionExpansionData;
use Modules\Qc\Entities\QualityInspectionExpansionHeader;

class QualityInspectionExpansionHeaderController extends Controller
{
    public function allRecords()
    {
        try {
            $query = "SELECT
            pp_customer_order_plans_data.manufacturing_order_no,
            st_products.product_name,
            qc_quality_inspection_expansion_headers.*,
            hr_employee_sites.site
        FROM
            st_products
            INNER JOIN
            pp_customer_order_plans_data
            INNER JOIN
            qc_quality_inspection_expansion_headers
            ON
                pp_customer_order_plans_data.customer_order_plan_data_id = qc_quality_inspection_expansion_headers.customer_order_plan_data_id AND
                st_products.product_primary_id = pp_customer_order_plans_data.product_id
            INNER JOIN
            hr_employee_sites
            ON
                qc_quality_inspection_expansion_headers.factory = hr_employee_sites.site_id
        GROUP BY
            qc_quality_inspection_expansion_headers.qi_expansion_id";

            $records = DB::select($query);
            $result = array();
            foreach ($records as $record) {
                array_push($result, [
                    "qi_expansion_id" => $record->qi_expansion_id,
                    "reference_no" => $record->reference_no,
                    "product_name" => $record->product_name,
                    "manufacturing_order_no" => $record->manufacturing_order_no,
                    "date" => $record->date,
                    "factory" => $record->site,
                ]);
            }
            $responseBody = $this->responseBody(true, "QualityInspectionExpansionHeaderController", "allRecords", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "QualityInspectionExpansionHeaderController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    public function deleteRecord($id)
    {
        try {
            if ($this->delete($id)) {
                $rec_head = QualityInspectionExpansionHeader::where('qi_expansion_id', '=', $id)->get();
                foreach ($rec_head as $data) {
                    $data->delete();
                }
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }

    public function delete($id)
    {
        try {
            $rec_data = QualityInspectionExpansionData::where('qi_expansion_id', '=', $id)->get();
            foreach ($rec_data as $data) {
                $data->delete();
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }

    public function qualityInspectionReport($id)
    {
        try {
            $query1 = "SELECT
            pp_customer_order_plans_data.manufacturing_order_no,
            st_products.product_name,
            qc_quality_inspection_expansion_headers.*,
            hr_employee_sites.site 
        FROM
            st_products
            INNER JOIN pp_customer_order_plans_data
            INNER JOIN qc_quality_inspection_expansion_headers ON pp_customer_order_plans_data.customer_order_plan_data_id = qc_quality_inspection_expansion_headers.customer_order_plan_data_id 
            AND st_products.product_primary_id = pp_customer_order_plans_data.product_id
            INNER JOIN hr_employee_sites ON qc_quality_inspection_expansion_headers.factory = hr_employee_sites.site_id 
        WHERE
            qc_quality_inspection_expansion_headers.qi_expansion_id = {$id}";

            $records = DB::select($query1);

            $header = [
                "factory_order_number" => "",
                "product_name" => "",
                "reference_no" => "",
                "date" => "",
            ];


            if ($records) {
                $header["factory_order_number"] = $records[0]->manufacturing_order_no;
                $header["product_name"] = $records[0]->product_name;
                $header["reference_no"] = $records[0]->reference_no;
                $header["date"] = $records[0]->date;
            }

            $query2 = "SELECT
            * 
        FROM
            qc_quality_inspection_expansion_data 
        WHERE
            qc_quality_inspection_expansion_data.qi_expansion_id = {$id}";

            $data = DB::select($query2);

            $records[0]->request_data = $data;


            $responseBody = $this->responseBody(true, "QualityInspectionExpansionHeaderController", "qualityInspectionReport", ["header" => $header, "body" => ["data" => $data]]);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "QualityInspectionExpansionHeaderController", "qualityInspectionReport", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }




    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}