<?php

namespace Modules\Qc\Http\Controllers;

use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Pp\Entities\Machinery;
use Modules\Qc\Entities\MaterialType;
use Modules\Hr\Entities\EmployeeSite;
use Modules\Qc\Entities\SupervisorCheckListHeader;
use Modules\Qc\Entities\SupervisorCheckListData;
use Modules\Qc\Entities\MachineRemarks;
use Modules\Qc\Entities\MaterialTypeRemarks;

class SupervisorCheckListDataController extends Controller
{
    public function getMachineryData()
    {
        try {
            $machine =  Machinery::all();
            $responseBody = $this->responseBody(true, "SupervisorCheckListDataController", "getMachineryData", $machine);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "SupervisorCheckListDataController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getMaterialData()
    {
        try {
            $material =  MaterialType::all();
            $responseBody = $this->responseBody(true, "SupervisorCheckListDataController", "getMaterialData", $material);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "SupervisorCheckListDataController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getFactoryData()
    {
        try {
            $factory = EmployeeSite::all();
            $responseBody = $this->responseBody(true, "SupervisorCheckListDataController", "getFactoryData", $factory);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "SupervisorCheckListDataController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function save(Request $request)
    {
        try {
            $rec = new SupervisorCheckListHeader();
            $rec->reference_no = $request->get('reference_no');
            $rec->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');   
            $rec->date = $request->get('date');
            $rec->shift_id = $request->get('shift_id');
            $rec->factory = $request->get('factory');
            if ($rec->save()) {

                $scl_rec = new SupervisorCheckListData();
                $scl_rec->scl_id = $rec->scl_id;
                $scl_rec->net_size = $request->get('net_size');
                $scl_rec->siever_magnet = $request->get('siever_magnet');
                $scl_rec->scales_mixing_area = $request->get('scales_mixing_area');
                $scl_rec->scales_finished_good_area = $request->get('scales_finished_good_area');
                $scl_rec->volume_bucket_accuracy = $request->get('volume_bucket_accuracy');
                $scl_rec->no_of_qcs = $request->get('no_of_qcs');
                $scl_rec->qc_allocated_places = $request->get('qc_allocated_places');
                $scl_rec->save();

                $rec_arr = $request->get("scl_data");
                $rec_material_arr = $request->get("scl_material_data");

                for ($i = 0; $i < count($rec_arr); $i++) {
                    $sclData = json_decode($rec_arr[$i]);
                    $rec_data = new MachineRemarks();
                    $rec_data->scl_id = $rec->scl_id;
                    $rec_data->machinery_id = $sclData->machinery_id;
                    $rec_data->remarks = $sclData->remarks;
                    $rec_data->save();
                }

                for ($i = 0; $i < count($rec_material_arr); $i++) {
                    $sclMaterialData = json_decode($rec_material_arr[$i]);
                    $rec_material_data = new MaterialTypeRemarks();
                    $rec_material_data->scl_id = $rec->scl_id;
                    $rec_material_data->mt_id = $sclMaterialData->mt_id;
                    $rec_material_data->remarks = $sclMaterialData->remarks;
                    $rec_material_data->save();
                }
            }
            $responseBody = $this->responseBody(true, "SupervisorCheckListDataController", "saved", true);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "SupervisorCheckListDataController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function getSclData($id)
    {
        try {
            $recordHead = SupervisorCheckListHeader::find($id);
            $recordData = SupervisorCheckListData::find($id);
            $recordMaterialData = MaterialTypeRemarks::where('scl_id', '=', $id)->get();
            $recordMachineData = MachineRemarks::where('scl_id', '=', $id)->get();


            $recordHead->request_data = $recordData;
            $recordHead->request_material_data = $recordMaterialData;
            $recordHead->request_machine_data = $recordMachineData;

            $responseBody = $this->responseBody(true, "SupervisorCheckListDataController", "getSclData", $recordHead);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "SupervisorCheckListDataController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    public function update(Request $request, $id)
    {

        try {

            if ($this->delete($id)) {
                $rec = SupervisorCheckListHeader::find($id);
                $rec->reference_no = $request->get('reference_no');
                $rec->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');            
                $rec->date = $request->get('date');
                $rec->shift_id = $request->get('shift_id');
                $rec->factory = $request->get('factory');
                $rec->update();

                $scl_rec = SupervisorCheckListData::find($id);
                $scl_rec->scl_id = $rec->scl_id;
                $scl_rec->net_size = $request->get('net_size');
                $scl_rec->siever_magnet = $request->get('siever_magnet');
                $scl_rec->scales_mixing_area = $request->get('scales_mixing_area');
                $scl_rec->scales_finished_good_area = $request->get('scales_finished_good_area');
                $scl_rec->volume_bucket_accuracy = $request->get('volume_bucket_accuracy');
                $scl_rec->no_of_qcs = $request->get('no_of_qcs');
                $scl_rec->qc_allocated_places = $request->get('qc_allocated_places');
                $scl_rec->save();

                $rec_machine_arr = $request->get("scl_data");
                $rec_material_arr = $request->get("scl_material_data");
                if ($rec_machine_arr) {
                    for ($i = 0; $i < count($rec_machine_arr); $i++) {
                        $sclMachineData = json_decode($rec_machine_arr[$i]);
                        $rec_data = new MachineRemarks();
                        $rec_data->scl_id = $rec->scl_id;
                        $rec_data->machinery_id = $sclMachineData->machinery_id;
                        $rec_data->remarks = $sclMachineData->remarks;
                        $rec_data->save();
                    }
                }

                if ($rec_material_arr) {
                    for ($i = 0; $i < count($rec_material_arr); $i++) {
                        $sclMaterialData = json_decode($rec_material_arr[$i]);
                        $rec_material_data = new MaterialTypeRemarks();
                        $rec_material_data->scl_id = $rec->scl_id;
                        $rec_material_data->mt_id = $sclMaterialData->mt_id;
                        $rec_material_data->remarks = $sclMaterialData->remarks;
                        $rec_material_data->save();
                    }
                }
            }

            $responseBody = $this->responseBody(true, "SupervisorCheckListDataController", "update", true);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "SupervisorCheckListDataController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function delete($id)
    {
        try {
            $rec_material_data = MaterialTypeRemarks::where('scl_id', '=', $id)->get();
            foreach ($rec_material_data as $data) {
                $data->delete();
            }
            $rec_machine_data = MachineRemarks::where('scl_id', '=', $id)->get();
            foreach ($rec_machine_data as $data) {
                $data->delete();
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }




    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
