$(document).ready(function () {
    $("#myTable").DataTable({
        scrollX: true,
        order: [],
        columns: [
            { data: "Reference No" },
            { data: "Product" },
            { data: "Factory Order Number" },
            { data: "Factory" },
            { data: "Shift" },
            { data: "Date" },
            { data: "edit", className: "edit", orderable: false },
            { data: "view", className: "view", orderable: false },
            { data: "print", className: "print", orderable: false },
            { data: "delete", className: "delete", orderable: false },
        ],
        columnDefs: [
            { width: 30, targets: 6 },
            { width: 30, targets: 7 },
            { width: 30, targets: 8 },
            { width: 30, targets: 9 },
        ],
    });

    allBiRecords();
});

function allBiRecords() {
    $.ajax({
        type: "GET",
        url: "/qc/DailyQualityBagInspectionDataHeaderController/records",
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () { },
        success: function (response) {
            if (response.data.success) {
                var data = [];

                for (i = 0; i < response.data.result.length; i++) {
                    var reference_no = response.data.result[i]["reference_no"];
                    var product_name = response.data.result[i]["product_name"];
                    var manufacturing_order_no =
                        response.data.result[i]["manufacturing_order_no"];
                    var factory = response.data.result[i]["factory"];
                    var shift = response.data.result[i]["shift"];
                    var date = response.data.result[i]["date"];
                    var dq_bag_inspection_id =
                        response.data.result[i]["dq_bag_inspection_id"];
                    data.push({
                        "Reference No": reference_no,
                        Product: product_name,
                        "Factory Order Number": manufacturing_order_no,
                        Factory: factory,
                        Shift: shift,
                        Date: date,
                        edit:
                            '<button class="btn btn-primary" onclick="edit(' +
                            dq_bag_inspection_id +
                            ')"><i class="fa fa-pencil-square-o" aria-hidden="true"></i></button>',
                        view:
                            '<button class="btn btn-success" onclick="view(' +
                            dq_bag_inspection_id +
                            ')"><i class="fa fa-eye" aria-hidden="true"></i></button>',
                        print:
                            '<button class="btn btn-instagram" onclick="print(' +
                            dq_bag_inspection_id +
                            ')"><i class="fa fa-print" aria-hidden="true"></i></button>',
                        delete:
                            '<button class="btn btn-danger" onclick="_delete(' +
                            dq_bag_inspection_id +
                            ')"><i class="fa fa-trash" aria-hidden="true"></i></button>',
                    });
                }

                var table = $("#myTable").DataTable();
                table.clear();
                table.rows.add(data).draw();
            }
        },

        error: function (error) {
            console.log(error);
        },
        complete: function () { },
    });
}

function edit(id) {
    location.href = "/qc/dqBagInspection?id=" + id + "&action=edit";
}

function view(id) {
    location.href = "/qc/dqBagInspection?id=" + id + "&action=view";
}

function _delete(id) {
    showAlert("Are You Sure?", id);
}

function showAlert(message, id) {
    swal({
        title: message,
        text: "Once deleted, you will not be able to recover this record!",
        icon: "warning",
        buttons: true,
        dangerMode: true,
    });

    $(".swal-button--confirm").on("click", function () {
        $.ajax({
            type: "DELETE",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            url:
                "/qc/DailyQualityBagInspectionDataHeaderController/delete/" +
                id,
            success: function (response) {
                console.log(response);
                allBiRecords();
            },
            error: function (data) {
                console.log(data);
            },
        });
    });
}

function print(id) {
    $.ajax({
        type: "GET",
        url:
            "/qc/DailyQualityBagInspectionDataHeaderController/bagInspectionReport/" +
            id,
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () { },
        success: function (response) {
            console.log(response);
            var result = response.data.result;
            console.log(result);
            bagInspectionListReport(result, "PRINT");
        },
        error: function (error) {
            console.log(error);
            showErrorMessage();
        },
        complete: function () { },
    });
}

function bagInspectionListReport(result, flag) {
    var headerFontSize = 8;
    var Title = [{ text: "" }];

    var header_data = result.header;

    var Header = [
        {
            content: [
                {
                    table: {
                        widths: ["*"],
                        headerRows: 1,
                        body: [
                            [
                                {
                                    text: Page.getReportName(),
                                    fontSize: 16,
                                    bold: true,
                                    alignment: "center",
                                    border: [false, false, false, false],
                                },
                            ],
                            [{
                                table: {
                                    widths: [150, '*', 150],
                                    headerRows: 1,
                                    body: [
                                        [{ rowSpan: 2, text: '', fontSize: 9, bold: false, alignment: 'left', border: [false, false, false, false] }, { rowSpan: 2, text: 'Daily Quality Bag Inspection Check List', fontSize: 14, bold: true, alignment: 'center', border: [false, false, false, false] }, { text: 'Document No : FO/PR/021', fontSize: 9, bold: false, alignment: 'right' }],
                                        [{}, {}, { text: 'Issue Date : 2017/05/03', fontSize: 9, bold: false, alignment: 'right' }],
                                    ],

                                }, border: [false, false, false, false]
                            }],
                            [
                                {
                                    table: {
                                        widths: ["*", 150],
                                        headerRows: 1,
                                        body: [
                                            [
                                                {
                                                    text:
                                                        "Reference No : " +
                                                        header_data.reference_no,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Product : " +
                                                        header_data.product,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                            [
                                                {
                                                    text: "",
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Factory Order Number : " +
                                                        header_data.factory_order_number,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                            [
                                                {
                                                    text: "",
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Factory : " +
                                                        header_data.factory,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                            [
                                                {
                                                    text: "",
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Size of The Product : " +
                                                        header_data.size_of_product,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                            [
                                                {
                                                    text: "",
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Shift : " +
                                                        header_data.shift,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                            [
                                                {
                                                    text: "",
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Date : " +
                                                        header_data.date,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                        ],
                                    },
                                    border: [false, false, false, false],
                                },
                            ],
                        ],
                    },
                    margin: [0, 0],
                },
            ],
        },
    ];

    var Body = [
        {
            table: {
                widths: [
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "auto",
                ],
                headerRows: 1,
                body: getBodyData(result.body),
            },
        },
        {
            table: {
                widths: ["*"],
                headerRows: 1,
                body: [
                    [
                        {
                            text: "PRD - Printing Damage, UD - Unsealing Damage, SB - Seal Burning, BD - Bag Damages, PDHD - Plant/Drain Hole Damage, RUD - Return Upside Down, PD - Production Damage, RE - Remarks",
                            fontSize: 7,
                            margin: [0, 5, 0, 0],
                            color: "gray",
                            bold: false,
                            alignment: "left",
                            border: [false, false, false, false],
                        },
                    ],
                ],
            },
            border: [false, false, false, false],
        },
        {
            margin: [0, 10],
            table: {
                widths: ['*', '*', '*'],
                headerRows: 1,
                heights: 10,
                margin: [10, 10],
                body: [
                    [{ text: 'Checked By', fontSize: 8, alignment: 'left', bold: true, colSpan: 3 }, {}, {}],
                    [{ text: 'Signature', fontSize: 8, alignment: 'left', bold: true, }, { text: 'Supervisor Name', fontSize: 8, alignment: 'left', bold: true, }, { text: 'Date', fontSize: 8, alignment: 'left', bold: true, }],
                    [{ text: '' }, { text: '' }, { text: '' }],
                ],

            }, border: [false, false, false, false]
        },
    ];

    var Footer = [
        {
            color: "red",
            fontSize: 8,
            alignment: "center",
            margin: [0, 0],
        },
    ];

    var page = new Page();
    page.setPageSize("A4");
    page.setPageOrientation("landscape");
    page.setPageMargin([10, 10, 10, 10]);
    page.setTitle(Title);
    page.setHeader(Header, Page.EVERY);
    page.setBody(Body);
    page.setFooter(Footer);
    if (flag == "EXPORT") {
        page.export();
    } else if (flag == "PRINT") {
        page.preview();
    }
}

function getBodyData(result) {
    var font_size = 8;
    var body = [];
    body.push([
        {
            text: "Hours",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "PRD",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "UD",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "SB",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "BD",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "PDHD",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "RUD",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "PD",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "QPRD",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "QUD",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "QSB",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "QBD",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "QPDHD",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "QRUD",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "QPD",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "Remarks",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
    ]);

    var data = result.data;
    for (i = 0; i < data.length; i++) {
        body.push([
            {
                text: data[i].hour,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].print_damage,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].unseal_damage,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].seal_burning,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].bag_damage,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].plant_hole_damage,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].upside_down,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].production_damage,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].qc_print_damage,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].qc_unseal_damage,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].qc_seal_burning,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].qc_bag_damage,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].qc_plant_hole_damage,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].qc_upside_down,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].qc_production_damage,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].remarks,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
        ]);
    }

    return body;
}

/**
 * showSuccessMessage
 * This function is used to show success message.
 * @param message This is the paramter to require message content
 */
function showSuccessMessage(message) {
    toastr.success(message);
}

/**
 * showWarningMessage
 * This function is used to show warning message.
 * @param message This is the paramter to require message content
 */
function showWarningMessage(message) {
    toastr.warning(message);
}

/**
 * showErrorMessage
 * This function is used to show error message.
 * @param message This is the paramter to require message content
 */
function showErrorMessage() {
    toastr.error("Something went wrong");
}
